"""
vtu_export
==========
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class vtu_export(Operator):
    """Export DPF data into vtu format.

    Parameters
    ----------
    directory : str
        Directory path
    base_name : str, optional
        Vtu base file name, (default is file)
    mesh : MeshedRegion
        Mesh
    fields1 : Field or FieldsContainer
        Nodal or elemental fields (over time) to
        export
    fields2 : Field or FieldsContainer
        Nodal or elemental fields (over time) to
        export
    write_mode : str, optional
        Available are rawbinarycompressed, rawbinary,
        base64appended, base64inline, ascii,
        default is (rawbinarycompressed)


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.serialization.vtu_export()

    >>> # Make input connections
    >>> my_directory = str()
    >>> op.inputs.directory.connect(my_directory)
    >>> my_base_name = str()
    >>> op.inputs.base_name.connect(my_base_name)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_fields1 = dpf.Field()
    >>> op.inputs.fields1.connect(my_fields1)
    >>> my_fields2 = dpf.Field()
    >>> op.inputs.fields2.connect(my_fields2)
    >>> my_write_mode = str()
    >>> op.inputs.write_mode.connect(my_write_mode)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.serialization.vtu_export(
    ...     directory=my_directory,
    ...     base_name=my_base_name,
    ...     mesh=my_mesh,
    ...     fields1=my_fields1,
    ...     fields2=my_fields2,
    ...     write_mode=my_write_mode,
    ... )

    >>> # Get output data
    >>> result_path = op.outputs.path()
    """

    def __init__(
        self,
        directory=None,
        base_name=None,
        mesh=None,
        fields1=None,
        fields2=None,
        write_mode=None,
        config=None,
        server=None,
    ):
        super().__init__(name="vtu_export", config=config, server=server)
        self._inputs = InputsVtuExport(self)
        self._outputs = OutputsVtuExport(self)
        if directory is not None:
            self.inputs.directory.connect(directory)
        if base_name is not None:
            self.inputs.base_name.connect(base_name)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)
        if fields1 is not None:
            self.inputs.fields1.connect(fields1)
        if fields2 is not None:
            self.inputs.fields2.connect(fields2)
        if write_mode is not None:
            self.inputs.write_mode.connect(write_mode)

    @staticmethod
    def _spec():
        description = """Export DPF data into vtu format."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="directory",
                    type_names=["string"],
                    optional=False,
                    document="""Directory path""",
                ),
                1: PinSpecification(
                    name="base_name",
                    type_names=["string"],
                    optional=True,
                    document="""Vtu base file name, (default is file)""",
                ),
                2: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=False,
                    document="""Mesh""",
                ),
                3: PinSpecification(
                    name="fields",
                    type_names=["field", "fields_container"],
                    optional=False,
                    document="""Nodal or elemental fields (over time) to
        export""",
                ),
                4: PinSpecification(
                    name="fields",
                    type_names=["field", "fields_container"],
                    optional=False,
                    document="""Nodal or elemental fields (over time) to
        export""",
                ),
                100: PinSpecification(
                    name="write_mode",
                    type_names=["string"],
                    optional=True,
                    document="""Available are rawbinarycompressed, rawbinary,
        base64appended, base64inline, ascii,
        default is (rawbinarycompressed)""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="path",
                    type_names=["data_sources"],
                    optional=False,
                    document="""List of output vtu file path""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="vtu_export", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsVtuExport
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsVtuExport
        """
        return super().outputs


class InputsVtuExport(_Inputs):
    """Intermediate class used to connect user inputs to
    vtu_export operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.serialization.vtu_export()
    >>> my_directory = str()
    >>> op.inputs.directory.connect(my_directory)
    >>> my_base_name = str()
    >>> op.inputs.base_name.connect(my_base_name)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_fields1 = dpf.Field()
    >>> op.inputs.fields1.connect(my_fields1)
    >>> my_fields2 = dpf.Field()
    >>> op.inputs.fields2.connect(my_fields2)
    >>> my_write_mode = str()
    >>> op.inputs.write_mode.connect(my_write_mode)
    """

    def __init__(self, op: Operator):
        super().__init__(vtu_export._spec().inputs, op)
        self._directory = Input(vtu_export._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._directory)
        self._base_name = Input(vtu_export._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._base_name)
        self._mesh = Input(vtu_export._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._mesh)
        self._fields1 = Input(vtu_export._spec().input_pin(3), 3, op, 0)
        self._inputs.append(self._fields1)
        self._fields2 = Input(vtu_export._spec().input_pin(4), 4, op, 1)
        self._inputs.append(self._fields2)
        self._write_mode = Input(vtu_export._spec().input_pin(100), 100, op, -1)
        self._inputs.append(self._write_mode)

    @property
    def directory(self):
        """Allows to connect directory input to the operator.

        Directory path

        Parameters
        ----------
        my_directory : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> op.inputs.directory.connect(my_directory)
        >>> # or
        >>> op.inputs.directory(my_directory)
        """
        return self._directory

    @property
    def base_name(self):
        """Allows to connect base_name input to the operator.

        Vtu base file name, (default is file)

        Parameters
        ----------
        my_base_name : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> op.inputs.base_name.connect(my_base_name)
        >>> # or
        >>> op.inputs.base_name(my_base_name)
        """
        return self._base_name

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Mesh

        Parameters
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh

    @property
    def fields1(self):
        """Allows to connect fields1 input to the operator.

        Nodal or elemental fields (over time) to
        export

        Parameters
        ----------
        my_fields1 : Field or FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> op.inputs.fields1.connect(my_fields1)
        >>> # or
        >>> op.inputs.fields1(my_fields1)
        """
        return self._fields1

    @property
    def fields2(self):
        """Allows to connect fields2 input to the operator.

        Nodal or elemental fields (over time) to
        export

        Parameters
        ----------
        my_fields2 : Field or FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> op.inputs.fields2.connect(my_fields2)
        >>> # or
        >>> op.inputs.fields2(my_fields2)
        """
        return self._fields2

    @property
    def write_mode(self):
        """Allows to connect write_mode input to the operator.

        Available are rawbinarycompressed, rawbinary,
        base64appended, base64inline, ascii,
        default is (rawbinarycompressed)

        Parameters
        ----------
        my_write_mode : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> op.inputs.write_mode.connect(my_write_mode)
        >>> # or
        >>> op.inputs.write_mode(my_write_mode)
        """
        return self._write_mode


class OutputsVtuExport(_Outputs):
    """Intermediate class used to get outputs from
    vtu_export operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.serialization.vtu_export()
    >>> # Connect inputs : op.inputs. ...
    >>> result_path = op.outputs.path()
    """

    def __init__(self, op: Operator):
        super().__init__(vtu_export._spec().outputs, op)
        self._path = Output(vtu_export._spec().output_pin(0), 0, op)
        self._outputs.append(self._path)

    @property
    def path(self):
        """Allows to get path output of the operator

        Returns
        ----------
        my_path : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.vtu_export()
        >>> # Connect inputs : op.inputs. ...
        >>> result_path = op.outputs.path()
        """  # noqa: E501
        return self._path



"""
element_nodal_contribution
==========================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class element_nodal_contribution(Operator):
    """Compute the fraction of the volume attributed to each node of each
    element.

    Parameters
    ----------
    mesh : MeshedRegion
    scoping : Scoping, optional
        Integrate the input field over a specific
        scoping.
    volume_fraction : bool, optional
        If true, returns influence volume. if false,
        returns the influence volume fraction
        (for example, the integrated value of
        shape function for each node).


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.geo.element_nodal_contribution()

    >>> # Make input connections
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)
    >>> my_volume_fraction = bool()
    >>> op.inputs.volume_fraction.connect(my_volume_fraction)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.geo.element_nodal_contribution(
    ...     mesh=my_mesh,
    ...     scoping=my_scoping,
    ...     volume_fraction=my_volume_fraction,
    ... )

    >>> # Get output data
    >>> result_field = op.outputs.field()
    """

    def __init__(
        self, mesh=None, scoping=None, volume_fraction=None, config=None, server=None
    ):
        super().__init__(
            name="element::nodal_contribution", config=config, server=server
        )
        self._inputs = InputsElementNodalContribution(self)
        self._outputs = OutputsElementNodalContribution(self)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)
        if scoping is not None:
            self.inputs.scoping.connect(scoping)
        if volume_fraction is not None:
            self.inputs.volume_fraction.connect(volume_fraction)

    @staticmethod
    def _spec():
        description = """Compute the fraction of the volume attributed to each node of each
            element."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="scoping",
                    type_names=["scoping"],
                    optional=True,
                    document="""Integrate the input field over a specific
        scoping.""",
                ),
                2: PinSpecification(
                    name="volume_fraction",
                    type_names=["bool"],
                    optional=True,
                    document="""If true, returns influence volume. if false,
        returns the influence volume fraction
        (for example, the integrated value of
        shape function for each node).""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(
            name="element::nodal_contribution", server=server
        )

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsElementNodalContribution
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsElementNodalContribution
        """
        return super().outputs


class InputsElementNodalContribution(_Inputs):
    """Intermediate class used to connect user inputs to
    element_nodal_contribution operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.geo.element_nodal_contribution()
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_scoping = dpf.Scoping()
    >>> op.inputs.scoping.connect(my_scoping)
    >>> my_volume_fraction = bool()
    >>> op.inputs.volume_fraction.connect(my_volume_fraction)
    """

    def __init__(self, op: Operator):
        super().__init__(element_nodal_contribution._spec().inputs, op)
        self._mesh = Input(element_nodal_contribution._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._mesh)
        self._scoping = Input(
            element_nodal_contribution._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._scoping)
        self._volume_fraction = Input(
            element_nodal_contribution._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._volume_fraction)

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Parameters
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.element_nodal_contribution()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh

    @property
    def scoping(self):
        """Allows to connect scoping input to the operator.

        Integrate the input field over a specific
        scoping.

        Parameters
        ----------
        my_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.element_nodal_contribution()
        >>> op.inputs.scoping.connect(my_scoping)
        >>> # or
        >>> op.inputs.scoping(my_scoping)
        """
        return self._scoping

    @property
    def volume_fraction(self):
        """Allows to connect volume_fraction input to the operator.

        If true, returns influence volume. if false,
        returns the influence volume fraction
        (for example, the integrated value of
        shape function for each node).

        Parameters
        ----------
        my_volume_fraction : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.element_nodal_contribution()
        >>> op.inputs.volume_fraction.connect(my_volume_fraction)
        >>> # or
        >>> op.inputs.volume_fraction(my_volume_fraction)
        """
        return self._volume_fraction


class OutputsElementNodalContribution(_Outputs):
    """Intermediate class used to get outputs from
    element_nodal_contribution operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.geo.element_nodal_contribution()
    >>> # Connect inputs : op.inputs. ...
    >>> result_field = op.outputs.field()
    """

    def __init__(self, op: Operator):
        super().__init__(element_nodal_contribution._spec().outputs, op)
        self._field = Output(element_nodal_contribution._spec().output_pin(0), 0, op)
        self._outputs.append(self._field)

    @property
    def field(self):
        """Allows to get field output of the operator

        Returns
        ----------
        my_field : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.geo.element_nodal_contribution()
        >>> # Connect inputs : op.inputs. ...
        >>> result_field = op.outputs.field()
        """  # noqa: E501
        return self._field



"""
remove_rigid_body_motion_fc
===========================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class remove_rigid_body_motion_fc(Operator):
    """Removes rigid body mode from a total displacement field by
    minimization. Use a reference point in order to subtract its
    displacement to the result displacement field.

    Parameters
    ----------
    fields_container : FieldsContainer
        Field or fields container with only one field
        is expected
    reference_node_id : int, optional
        Id of the reference entity (node).
    mesh : MeshedRegion, optional
        Default is the mesh in the support


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.result.remove_rigid_body_motion_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_reference_node_id = int()
    >>> op.inputs.reference_node_id.connect(my_reference_node_id)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.result.remove_rigid_body_motion_fc(
    ...     fields_container=my_fields_container,
    ...     reference_node_id=my_reference_node_id,
    ...     mesh=my_mesh,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self,
        fields_container=None,
        reference_node_id=None,
        mesh=None,
        config=None,
        server=None,
    ):
        super().__init__(name="ExtractRigidBodyMotion_fc", config=config, server=server)
        self._inputs = InputsRemoveRigidBodyMotionFc(self)
        self._outputs = OutputsRemoveRigidBodyMotionFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if reference_node_id is not None:
            self.inputs.reference_node_id.connect(reference_node_id)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)

    @staticmethod
    def _spec():
        description = """Removes rigid body mode from a total displacement field by
            minimization. Use a reference point in order to subtract
            its displacement to the result displacement field."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Field or fields container with only one field
        is expected""",
                ),
                1: PinSpecification(
                    name="reference_node_id",
                    type_names=["int32"],
                    optional=True,
                    document="""Id of the reference entity (node).""",
                ),
                7: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region"],
                    optional=True,
                    document="""Default is the mesh in the support""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="ExtractRigidBodyMotion_fc", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsRemoveRigidBodyMotionFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsRemoveRigidBodyMotionFc
        """
        return super().outputs


class InputsRemoveRigidBodyMotionFc(_Inputs):
    """Intermediate class used to connect user inputs to
    remove_rigid_body_motion_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.remove_rigid_body_motion_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_reference_node_id = int()
    >>> op.inputs.reference_node_id.connect(my_reference_node_id)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    """

    def __init__(self, op: Operator):
        super().__init__(remove_rigid_body_motion_fc._spec().inputs, op)
        self._fields_container = Input(
            remove_rigid_body_motion_fc._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._reference_node_id = Input(
            remove_rigid_body_motion_fc._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._reference_node_id)
        self._mesh = Input(remove_rigid_body_motion_fc._spec().input_pin(7), 7, op, -1)
        self._inputs.append(self._mesh)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Field or fields container with only one field
        is expected

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.remove_rigid_body_motion_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def reference_node_id(self):
        """Allows to connect reference_node_id input to the operator.

        Id of the reference entity (node).

        Parameters
        ----------
        my_reference_node_id : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.remove_rigid_body_motion_fc()
        >>> op.inputs.reference_node_id.connect(my_reference_node_id)
        >>> # or
        >>> op.inputs.reference_node_id(my_reference_node_id)
        """
        return self._reference_node_id

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Default is the mesh in the support

        Parameters
        ----------
        my_mesh : MeshedRegion

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.remove_rigid_body_motion_fc()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh


class OutputsRemoveRigidBodyMotionFc(_Outputs):
    """Intermediate class used to get outputs from
    remove_rigid_body_motion_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.remove_rigid_body_motion_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(remove_rigid_body_motion_fc._spec().outputs, op)
        self._fields_container = Output(
            remove_rigid_body_motion_fc._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.remove_rigid_body_motion_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
global_total_mass
=================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class global_total_mass(Operator):
    """Read Global Total Mass (LSDyna) by calling the readers defined by the
    datasources.

    Parameters
    ----------
    streams_container : StreamsContainer, optional
        Result file container allowed to be kept open
        to cache data
    data_sources : DataSources
        Result file path container, used if no
        streams are set
    unit_system : int or str or UnitSystem, optional
        Unit system id (int), semicolon-separated
        list of base unit strings (str) or
        unitsystem instance


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.result.global_total_mass()

    >>> # Make input connections
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_unit_system = int()
    >>> op.inputs.unit_system.connect(my_unit_system)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.result.global_total_mass(
    ...     streams_container=my_streams_container,
    ...     data_sources=my_data_sources,
    ...     unit_system=my_unit_system,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self,
        streams_container=None,
        data_sources=None,
        unit_system=None,
        config=None,
        server=None,
    ):
        super().__init__(name="GLOB_TM", config=config, server=server)
        self._inputs = InputsGlobalTotalMass(self)
        self._outputs = OutputsGlobalTotalMass(self)
        if streams_container is not None:
            self.inputs.streams_container.connect(streams_container)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)
        if unit_system is not None:
            self.inputs.unit_system.connect(unit_system)

    @staticmethod
    def _spec():
        description = """Read Global Total Mass (LSDyna) by calling the readers defined by the
            datasources."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                3: PinSpecification(
                    name="streams_container",
                    type_names=["streams_container"],
                    optional=True,
                    document="""Result file container allowed to be kept open
        to cache data""",
                ),
                4: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""Result file path container, used if no
        streams are set""",
                ),
                50: PinSpecification(
                    name="unit_system",
                    type_names=[
                        "int32",
                        "string",
                        "class dataProcessing::unit::CUnitSystem",
                    ],
                    optional=True,
                    document="""Unit system id (int), semicolon-separated
        list of base unit strings (str) or
        unitsystem instance""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="GLOB_TM", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsGlobalTotalMass
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsGlobalTotalMass
        """
        return super().outputs


class InputsGlobalTotalMass(_Inputs):
    """Intermediate class used to connect user inputs to
    global_total_mass operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.global_total_mass()
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_unit_system = int()
    >>> op.inputs.unit_system.connect(my_unit_system)
    """

    def __init__(self, op: Operator):
        super().__init__(global_total_mass._spec().inputs, op)
        self._streams_container = Input(
            global_total_mass._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._streams_container)
        self._data_sources = Input(global_total_mass._spec().input_pin(4), 4, op, -1)
        self._inputs.append(self._data_sources)
        self._unit_system = Input(global_total_mass._spec().input_pin(50), 50, op, -1)
        self._inputs.append(self._unit_system)

    @property
    def streams_container(self):
        """Allows to connect streams_container input to the operator.

        Result file container allowed to be kept open
        to cache data

        Parameters
        ----------
        my_streams_container : StreamsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.global_total_mass()
        >>> op.inputs.streams_container.connect(my_streams_container)
        >>> # or
        >>> op.inputs.streams_container(my_streams_container)
        """
        return self._streams_container

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        Result file path container, used if no
        streams are set

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.global_total_mass()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources

    @property
    def unit_system(self):
        """Allows to connect unit_system input to the operator.

        Unit system id (int), semicolon-separated
        list of base unit strings (str) or
        unitsystem instance

        Parameters
        ----------
        my_unit_system : int or str or UnitSystem

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.global_total_mass()
        >>> op.inputs.unit_system.connect(my_unit_system)
        >>> # or
        >>> op.inputs.unit_system(my_unit_system)
        """
        return self._unit_system


class OutputsGlobalTotalMass(_Outputs):
    """Intermediate class used to get outputs from
    global_total_mass operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.global_total_mass()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(global_total_mass._spec().outputs, op)
        self._fields_container = Output(global_total_mass._spec().output_pin(0), 0, op)
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.global_total_mass()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
scoping_band_pass
=================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class scoping_band_pass(Operator):
    """The band pass filter returns all the values above (but not equal to)
    the minimum threshold value and below (but not equal to) the
    maximum threshold value in input.

    Parameters
    ----------
    field : Field or FieldsContainer
        Field or fields container with only one field
        is expected
    min_threshold : float or Field
        A minimum threshold scalar or a field
        containing one value is expected.
    max_threshold : float or Field, optional
        A maximum threshold scalar or a field
        containing one value is expected.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.filter.scoping_band_pass()

    >>> # Make input connections
    >>> my_field = dpf.Field()
    >>> op.inputs.field.connect(my_field)
    >>> my_min_threshold = float()
    >>> op.inputs.min_threshold.connect(my_min_threshold)
    >>> my_max_threshold = float()
    >>> op.inputs.max_threshold.connect(my_max_threshold)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.filter.scoping_band_pass(
    ...     field=my_field,
    ...     min_threshold=my_min_threshold,
    ...     max_threshold=my_max_threshold,
    ... )

    >>> # Get output data
    >>> result_scoping = op.outputs.scoping()
    """

    def __init__(
        self,
        field=None,
        min_threshold=None,
        max_threshold=None,
        config=None,
        server=None,
    ):
        super().__init__(name="core::scoping::band_pass", config=config, server=server)
        self._inputs = InputsScopingBandPass(self)
        self._outputs = OutputsScopingBandPass(self)
        if field is not None:
            self.inputs.field.connect(field)
        if min_threshold is not None:
            self.inputs.min_threshold.connect(min_threshold)
        if max_threshold is not None:
            self.inputs.max_threshold.connect(max_threshold)

    @staticmethod
    def _spec():
        description = """The band pass filter returns all the values above (but not equal to)
            the minimum threshold value and below (but not equal to)
            the maximum threshold value in input."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="field",
                    type_names=["field", "fields_container"],
                    optional=False,
                    document="""Field or fields container with only one field
        is expected""",
                ),
                1: PinSpecification(
                    name="min_threshold",
                    type_names=["double", "field"],
                    optional=False,
                    document="""A minimum threshold scalar or a field
        containing one value is expected.""",
                ),
                2: PinSpecification(
                    name="max_threshold",
                    type_names=["double", "field"],
                    optional=True,
                    document="""A maximum threshold scalar or a field
        containing one value is expected.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="scoping",
                    type_names=["scoping"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="core::scoping::band_pass", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsScopingBandPass
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsScopingBandPass
        """
        return super().outputs


class InputsScopingBandPass(_Inputs):
    """Intermediate class used to connect user inputs to
    scoping_band_pass operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.filter.scoping_band_pass()
    >>> my_field = dpf.Field()
    >>> op.inputs.field.connect(my_field)
    >>> my_min_threshold = float()
    >>> op.inputs.min_threshold.connect(my_min_threshold)
    >>> my_max_threshold = float()
    >>> op.inputs.max_threshold.connect(my_max_threshold)
    """

    def __init__(self, op: Operator):
        super().__init__(scoping_band_pass._spec().inputs, op)
        self._field = Input(scoping_band_pass._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._field)
        self._min_threshold = Input(scoping_band_pass._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._min_threshold)
        self._max_threshold = Input(scoping_band_pass._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._max_threshold)

    @property
    def field(self):
        """Allows to connect field input to the operator.

        Field or fields container with only one field
        is expected

        Parameters
        ----------
        my_field : Field or FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.scoping_band_pass()
        >>> op.inputs.field.connect(my_field)
        >>> # or
        >>> op.inputs.field(my_field)
        """
        return self._field

    @property
    def min_threshold(self):
        """Allows to connect min_threshold input to the operator.

        A minimum threshold scalar or a field
        containing one value is expected.

        Parameters
        ----------
        my_min_threshold : float or Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.scoping_band_pass()
        >>> op.inputs.min_threshold.connect(my_min_threshold)
        >>> # or
        >>> op.inputs.min_threshold(my_min_threshold)
        """
        return self._min_threshold

    @property
    def max_threshold(self):
        """Allows to connect max_threshold input to the operator.

        A maximum threshold scalar or a field
        containing one value is expected.

        Parameters
        ----------
        my_max_threshold : float or Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.scoping_band_pass()
        >>> op.inputs.max_threshold.connect(my_max_threshold)
        >>> # or
        >>> op.inputs.max_threshold(my_max_threshold)
        """
        return self._max_threshold


class OutputsScopingBandPass(_Outputs):
    """Intermediate class used to get outputs from
    scoping_band_pass operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.filter.scoping_band_pass()
    >>> # Connect inputs : op.inputs. ...
    >>> result_scoping = op.outputs.scoping()
    """

    def __init__(self, op: Operator):
        super().__init__(scoping_band_pass._spec().outputs, op)
        self._scoping = Output(scoping_band_pass._spec().output_pin(0), 0, op)
        self._outputs.append(self._scoping)

    @property
    def scoping(self):
        """Allows to get scoping output of the operator

        Returns
        ----------
        my_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.scoping_band_pass()
        >>> # Connect inputs : op.inputs. ...
        >>> result_scoping = op.outputs.scoping()
        """  # noqa: E501
        return self._scoping



"""
elemental_to_nodal_fc
=====================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class elemental_to_nodal_fc(Operator):
    """Transforms Elemental Nodal fields to Nodal fields. The result is
    computed on a given node's scoping.1. For a finite element mesh,
    the value on a node is the average of the values of the neighbour
    elements.  2. For a finite volume mesh, the agorithm is :    - For
    each node, compute interpolation weights for the cells connected
    to it based   on the Frink's Laplacian method.         - If the
    determinant of the I matrix is zero, switch to an inverse distance
    weighted average.         - If not, compute the Frink weights and
    apply the Holmes' weight clip.         - If the clipping produces
    a large overshoot, inverse volume weighted average is used.. 3.
    For a face finite volume mesh inverse distance weighted average is
    used.

    Parameters
    ----------
    fields_container : FieldsContainer
    mesh : MeshedRegion or MeshesContainer, optional
    force_averaging : int, optional
        Averaging on nodes is used if this pin is set
        to 1 (default is 1 for integrated
        results and 0 for discrete ones).
    mesh_scoping : Scoping or ScopingsContainer, optional
    algorithm : int, optional
        Forces the usage of algorithm 1, 2 or 3
        (default is chosen based on the type
        of mesh).


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.averaging.elemental_to_nodal_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_force_averaging = int()
    >>> op.inputs.force_averaging.connect(my_force_averaging)
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_algorithm = int()
    >>> op.inputs.algorithm.connect(my_algorithm)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.averaging.elemental_to_nodal_fc(
    ...     fields_container=my_fields_container,
    ...     mesh=my_mesh,
    ...     force_averaging=my_force_averaging,
    ...     mesh_scoping=my_mesh_scoping,
    ...     algorithm=my_algorithm,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self,
        fields_container=None,
        mesh=None,
        force_averaging=None,
        mesh_scoping=None,
        algorithm=None,
        config=None,
        server=None,
    ):
        super().__init__(name="elemental_to_nodal_fc", config=config, server=server)
        self._inputs = InputsElementalToNodalFc(self)
        self._outputs = OutputsElementalToNodalFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if mesh is not None:
            self.inputs.mesh.connect(mesh)
        if force_averaging is not None:
            self.inputs.force_averaging.connect(force_averaging)
        if mesh_scoping is not None:
            self.inputs.mesh_scoping.connect(mesh_scoping)
        if algorithm is not None:
            self.inputs.algorithm.connect(algorithm)

    @staticmethod
    def _spec():
        description = """Transforms Elemental Nodal fields to Nodal fields. The result is
            computed on a given node's scoping.1. For a finite element
            mesh, the value on a node is the average of the values of
            the neighbour elements.  2. For a finite volume mesh, the
            agorithm is :    - For each node, compute interpolation
            weights for the cells connected to it based   on the
            Frink's Laplacian method.         - If the determinant of
            the I matrix is zero, switch to an inverse distance
            weighted average.         - If not, compute the Frink
            weights and apply the Holmes' weight clip.         - If
            the clipping produces a large overshoot, inverse volume
            weighted average is used.. 3. For a face finite volume
            mesh inverse distance weighted average is used."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="mesh",
                    type_names=["abstract_meshed_region", "meshes_container"],
                    optional=True,
                    document="""""",
                ),
                2: PinSpecification(
                    name="force_averaging",
                    type_names=["int32"],
                    optional=True,
                    document="""Averaging on nodes is used if this pin is set
        to 1 (default is 1 for integrated
        results and 0 for discrete ones).""",
                ),
                3: PinSpecification(
                    name="mesh_scoping",
                    type_names=["scoping", "scopings_container"],
                    optional=True,
                    document="""""",
                ),
                200: PinSpecification(
                    name="algorithm",
                    type_names=["int32"],
                    optional=True,
                    document="""Forces the usage of algorithm 1, 2 or 3
        (default is chosen based on the type
        of mesh).""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="elemental_to_nodal_fc", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsElementalToNodalFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsElementalToNodalFc
        """
        return super().outputs


class InputsElementalToNodalFc(_Inputs):
    """Intermediate class used to connect user inputs to
    elemental_to_nodal_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_mesh = dpf.MeshedRegion()
    >>> op.inputs.mesh.connect(my_mesh)
    >>> my_force_averaging = int()
    >>> op.inputs.force_averaging.connect(my_force_averaging)
    >>> my_mesh_scoping = dpf.Scoping()
    >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
    >>> my_algorithm = int()
    >>> op.inputs.algorithm.connect(my_algorithm)
    """

    def __init__(self, op: Operator):
        super().__init__(elemental_to_nodal_fc._spec().inputs, op)
        self._fields_container = Input(
            elemental_to_nodal_fc._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._mesh = Input(elemental_to_nodal_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._mesh)
        self._force_averaging = Input(
            elemental_to_nodal_fc._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._force_averaging)
        self._mesh_scoping = Input(
            elemental_to_nodal_fc._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._mesh_scoping)
        self._algorithm = Input(
            elemental_to_nodal_fc._spec().input_pin(200), 200, op, -1
        )
        self._inputs.append(self._algorithm)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def mesh(self):
        """Allows to connect mesh input to the operator.

        Parameters
        ----------
        my_mesh : MeshedRegion or MeshesContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
        >>> op.inputs.mesh.connect(my_mesh)
        >>> # or
        >>> op.inputs.mesh(my_mesh)
        """
        return self._mesh

    @property
    def force_averaging(self):
        """Allows to connect force_averaging input to the operator.

        Averaging on nodes is used if this pin is set
        to 1 (default is 1 for integrated
        results and 0 for discrete ones).

        Parameters
        ----------
        my_force_averaging : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
        >>> op.inputs.force_averaging.connect(my_force_averaging)
        >>> # or
        >>> op.inputs.force_averaging(my_force_averaging)
        """
        return self._force_averaging

    @property
    def mesh_scoping(self):
        """Allows to connect mesh_scoping input to the operator.

        Parameters
        ----------
        my_mesh_scoping : Scoping or ScopingsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
        >>> op.inputs.mesh_scoping.connect(my_mesh_scoping)
        >>> # or
        >>> op.inputs.mesh_scoping(my_mesh_scoping)
        """
        return self._mesh_scoping

    @property
    def algorithm(self):
        """Allows to connect algorithm input to the operator.

        Forces the usage of algorithm 1, 2 or 3
        (default is chosen based on the type
        of mesh).

        Parameters
        ----------
        my_algorithm : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
        >>> op.inputs.algorithm.connect(my_algorithm)
        >>> # or
        >>> op.inputs.algorithm(my_algorithm)
        """
        return self._algorithm


class OutputsElementalToNodalFc(_Outputs):
    """Intermediate class used to get outputs from
    elemental_to_nodal_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(elemental_to_nodal_fc._spec().outputs, op)
        self._fields_container = Output(
            elemental_to_nodal_fc._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.averaging.elemental_to_nodal_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



"""
write_cms_rbd_file
==================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class write_cms_rbd_file(Operator):
    """Write the invariant terms and the model data in a cms_rbd file

    Parameters
    ----------
    model_data : PropertyField
        Data describing the finite element model
    center_of_mass : Field
        Center of mass of the body
    inertia_relief : Field
        Inertia matrix
    model_size : float
        Size of the diagonal box containing the body
    master_node_coordinates :
    v_trsf :
        Translational and rotational shape functions
    k_mat : Field
    mass_mat : Field
    c_mat : Field
    rhs : Field
    dn :
    dr_cross_n :
    drn :
    dn_cross_n :
    dnx_y :
    dny_y :
    dnz_y :
    dyx_n :
    dyy_n :
    dyz_n :
    dnxn :
    dnyn :
    dnzn :
    file_path : str
        Path with cms_rbd extension where the export
        occurs


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.result.write_cms_rbd_file()

    >>> # Make input connections
    >>> my_model_data = dpf.PropertyField()
    >>> op.inputs.model_data.connect(my_model_data)
    >>> my_center_of_mass = dpf.Field()
    >>> op.inputs.center_of_mass.connect(my_center_of_mass)
    >>> my_inertia_relief = dpf.Field()
    >>> op.inputs.inertia_relief.connect(my_inertia_relief)
    >>> my_model_size = float()
    >>> op.inputs.model_size.connect(my_model_size)
    >>> my_master_node_coordinates = dpf.()
    >>> op.inputs.master_node_coordinates.connect(my_master_node_coordinates)
    >>> my_v_trsf = dpf.()
    >>> op.inputs.v_trsf.connect(my_v_trsf)
    >>> my_k_mat = dpf.Field()
    >>> op.inputs.k_mat.connect(my_k_mat)
    >>> my_mass_mat = dpf.Field()
    >>> op.inputs.mass_mat.connect(my_mass_mat)
    >>> my_c_mat = dpf.Field()
    >>> op.inputs.c_mat.connect(my_c_mat)
    >>> my_rhs = dpf.Field()
    >>> op.inputs.rhs.connect(my_rhs)
    >>> my_dn = dpf.()
    >>> op.inputs.dn.connect(my_dn)
    >>> my_dr_cross_n = dpf.()
    >>> op.inputs.dr_cross_n.connect(my_dr_cross_n)
    >>> my_drn = dpf.()
    >>> op.inputs.drn.connect(my_drn)
    >>> my_dn_cross_n = dpf.()
    >>> op.inputs.dn_cross_n.connect(my_dn_cross_n)
    >>> my_dnx_y = dpf.()
    >>> op.inputs.dnx_y.connect(my_dnx_y)
    >>> my_dny_y = dpf.()
    >>> op.inputs.dny_y.connect(my_dny_y)
    >>> my_dnz_y = dpf.()
    >>> op.inputs.dnz_y.connect(my_dnz_y)
    >>> my_dyx_n = dpf.()
    >>> op.inputs.dyx_n.connect(my_dyx_n)
    >>> my_dyy_n = dpf.()
    >>> op.inputs.dyy_n.connect(my_dyy_n)
    >>> my_dyz_n = dpf.()
    >>> op.inputs.dyz_n.connect(my_dyz_n)
    >>> my_dnxn = dpf.()
    >>> op.inputs.dnxn.connect(my_dnxn)
    >>> my_dnyn = dpf.()
    >>> op.inputs.dnyn.connect(my_dnyn)
    >>> my_dnzn = dpf.()
    >>> op.inputs.dnzn.connect(my_dnzn)
    >>> my_file_path = str()
    >>> op.inputs.file_path.connect(my_file_path)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.result.write_cms_rbd_file(
    ...     model_data=my_model_data,
    ...     center_of_mass=my_center_of_mass,
    ...     inertia_relief=my_inertia_relief,
    ...     model_size=my_model_size,
    ...     master_node_coordinates=my_master_node_coordinates,
    ...     v_trsf=my_v_trsf,
    ...     k_mat=my_k_mat,
    ...     mass_mat=my_mass_mat,
    ...     c_mat=my_c_mat,
    ...     rhs=my_rhs,
    ...     dn=my_dn,
    ...     dr_cross_n=my_dr_cross_n,
    ...     drn=my_drn,
    ...     dn_cross_n=my_dn_cross_n,
    ...     dnx_y=my_dnx_y,
    ...     dny_y=my_dny_y,
    ...     dnz_y=my_dnz_y,
    ...     dyx_n=my_dyx_n,
    ...     dyy_n=my_dyy_n,
    ...     dyz_n=my_dyz_n,
    ...     dnxn=my_dnxn,
    ...     dnyn=my_dnyn,
    ...     dnzn=my_dnzn,
    ...     file_path=my_file_path,
    ... )

    """

    def __init__(
        self,
        model_data=None,
        center_of_mass=None,
        inertia_relief=None,
        model_size=None,
        master_node_coordinates=None,
        v_trsf=None,
        k_mat=None,
        mass_mat=None,
        c_mat=None,
        rhs=None,
        dn=None,
        dr_cross_n=None,
        drn=None,
        dn_cross_n=None,
        dnx_y=None,
        dny_y=None,
        dnz_y=None,
        dyx_n=None,
        dyy_n=None,
        dyz_n=None,
        dnxn=None,
        dnyn=None,
        dnzn=None,
        file_path=None,
        config=None,
        server=None,
    ):
        super().__init__(name="write_cms_rbd_file", config=config, server=server)
        self._inputs = InputsWriteCmsRbdFile(self)
        self._outputs = OutputsWriteCmsRbdFile(self)
        if model_data is not None:
            self.inputs.model_data.connect(model_data)
        if center_of_mass is not None:
            self.inputs.center_of_mass.connect(center_of_mass)
        if inertia_relief is not None:
            self.inputs.inertia_relief.connect(inertia_relief)
        if model_size is not None:
            self.inputs.model_size.connect(model_size)
        if master_node_coordinates is not None:
            self.inputs.master_node_coordinates.connect(master_node_coordinates)
        if v_trsf is not None:
            self.inputs.v_trsf.connect(v_trsf)
        if k_mat is not None:
            self.inputs.k_mat.connect(k_mat)
        if mass_mat is not None:
            self.inputs.mass_mat.connect(mass_mat)
        if c_mat is not None:
            self.inputs.c_mat.connect(c_mat)
        if rhs is not None:
            self.inputs.rhs.connect(rhs)
        if dn is not None:
            self.inputs.dn.connect(dn)
        if dr_cross_n is not None:
            self.inputs.dr_cross_n.connect(dr_cross_n)
        if drn is not None:
            self.inputs.drn.connect(drn)
        if dn_cross_n is not None:
            self.inputs.dn_cross_n.connect(dn_cross_n)
        if dnx_y is not None:
            self.inputs.dnx_y.connect(dnx_y)
        if dny_y is not None:
            self.inputs.dny_y.connect(dny_y)
        if dnz_y is not None:
            self.inputs.dnz_y.connect(dnz_y)
        if dyx_n is not None:
            self.inputs.dyx_n.connect(dyx_n)
        if dyy_n is not None:
            self.inputs.dyy_n.connect(dyy_n)
        if dyz_n is not None:
            self.inputs.dyz_n.connect(dyz_n)
        if dnxn is not None:
            self.inputs.dnxn.connect(dnxn)
        if dnyn is not None:
            self.inputs.dnyn.connect(dnyn)
        if dnzn is not None:
            self.inputs.dnzn.connect(dnzn)
        if file_path is not None:
            self.inputs.file_path.connect(file_path)

    @staticmethod
    def _spec():
        description = (
            """Write the invariant terms and the model data in a cms_rbd file"""
        )
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="model_data",
                    type_names=["property_field"],
                    optional=False,
                    document="""Data describing the finite element model""",
                ),
                1: PinSpecification(
                    name="center_of_mass",
                    type_names=["field"],
                    optional=False,
                    document="""Center of mass of the body""",
                ),
                2: PinSpecification(
                    name="inertia_relief",
                    type_names=["field"],
                    optional=False,
                    document="""Inertia matrix""",
                ),
                3: PinSpecification(
                    name="model_size",
                    type_names=["double"],
                    optional=False,
                    document="""Size of the diagonal box containing the body""",
                ),
                4: PinSpecification(
                    name="master_node_coordinates",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                5: PinSpecification(
                    name="v_trsf",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""Translational and rotational shape functions""",
                ),
                6: PinSpecification(
                    name="k_mat",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
                7: PinSpecification(
                    name="mass_mat",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
                8: PinSpecification(
                    name="c_mat",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
                9: PinSpecification(
                    name="rhs",
                    type_names=["field"],
                    optional=False,
                    document="""""",
                ),
                10: PinSpecification(
                    name="dn",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                11: PinSpecification(
                    name="dr_cross_n",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                12: PinSpecification(
                    name="drn",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                13: PinSpecification(
                    name="dn_cross_n",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                14: PinSpecification(
                    name="dnx_y",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                15: PinSpecification(
                    name="dny_y",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                16: PinSpecification(
                    name="dnz_y",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                17: PinSpecification(
                    name="dyx_n",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                18: PinSpecification(
                    name="dyy_n",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                19: PinSpecification(
                    name="dyz_n",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                20: PinSpecification(
                    name="dnxn",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                21: PinSpecification(
                    name="dnyn",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                22: PinSpecification(
                    name="dnzn",
                    type_names=["vector<double>"],
                    optional=False,
                    document="""""",
                ),
                23: PinSpecification(
                    name="file_path",
                    type_names=["string"],
                    optional=False,
                    document="""Path with cms_rbd extension where the export
        occurs""",
                ),
            },
            map_output_pin_spec={},
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="write_cms_rbd_file", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsWriteCmsRbdFile
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsWriteCmsRbdFile
        """
        return super().outputs


class InputsWriteCmsRbdFile(_Inputs):
    """Intermediate class used to connect user inputs to
    write_cms_rbd_file operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.write_cms_rbd_file()
    >>> my_model_data = dpf.PropertyField()
    >>> op.inputs.model_data.connect(my_model_data)
    >>> my_center_of_mass = dpf.Field()
    >>> op.inputs.center_of_mass.connect(my_center_of_mass)
    >>> my_inertia_relief = dpf.Field()
    >>> op.inputs.inertia_relief.connect(my_inertia_relief)
    >>> my_model_size = float()
    >>> op.inputs.model_size.connect(my_model_size)
    >>> my_master_node_coordinates = dpf.()
    >>> op.inputs.master_node_coordinates.connect(my_master_node_coordinates)
    >>> my_v_trsf = dpf.()
    >>> op.inputs.v_trsf.connect(my_v_trsf)
    >>> my_k_mat = dpf.Field()
    >>> op.inputs.k_mat.connect(my_k_mat)
    >>> my_mass_mat = dpf.Field()
    >>> op.inputs.mass_mat.connect(my_mass_mat)
    >>> my_c_mat = dpf.Field()
    >>> op.inputs.c_mat.connect(my_c_mat)
    >>> my_rhs = dpf.Field()
    >>> op.inputs.rhs.connect(my_rhs)
    >>> my_dn = dpf.()
    >>> op.inputs.dn.connect(my_dn)
    >>> my_dr_cross_n = dpf.()
    >>> op.inputs.dr_cross_n.connect(my_dr_cross_n)
    >>> my_drn = dpf.()
    >>> op.inputs.drn.connect(my_drn)
    >>> my_dn_cross_n = dpf.()
    >>> op.inputs.dn_cross_n.connect(my_dn_cross_n)
    >>> my_dnx_y = dpf.()
    >>> op.inputs.dnx_y.connect(my_dnx_y)
    >>> my_dny_y = dpf.()
    >>> op.inputs.dny_y.connect(my_dny_y)
    >>> my_dnz_y = dpf.()
    >>> op.inputs.dnz_y.connect(my_dnz_y)
    >>> my_dyx_n = dpf.()
    >>> op.inputs.dyx_n.connect(my_dyx_n)
    >>> my_dyy_n = dpf.()
    >>> op.inputs.dyy_n.connect(my_dyy_n)
    >>> my_dyz_n = dpf.()
    >>> op.inputs.dyz_n.connect(my_dyz_n)
    >>> my_dnxn = dpf.()
    >>> op.inputs.dnxn.connect(my_dnxn)
    >>> my_dnyn = dpf.()
    >>> op.inputs.dnyn.connect(my_dnyn)
    >>> my_dnzn = dpf.()
    >>> op.inputs.dnzn.connect(my_dnzn)
    >>> my_file_path = str()
    >>> op.inputs.file_path.connect(my_file_path)
    """

    def __init__(self, op: Operator):
        super().__init__(write_cms_rbd_file._spec().inputs, op)
        self._model_data = Input(write_cms_rbd_file._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._model_data)
        self._center_of_mass = Input(write_cms_rbd_file._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._center_of_mass)
        self._inertia_relief = Input(write_cms_rbd_file._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._inertia_relief)
        self._model_size = Input(write_cms_rbd_file._spec().input_pin(3), 3, op, -1)
        self._inputs.append(self._model_size)
        self._master_node_coordinates = Input(
            write_cms_rbd_file._spec().input_pin(4), 4, op, -1
        )
        self._inputs.append(self._master_node_coordinates)
        self._v_trsf = Input(write_cms_rbd_file._spec().input_pin(5), 5, op, -1)
        self._inputs.append(self._v_trsf)
        self._k_mat = Input(write_cms_rbd_file._spec().input_pin(6), 6, op, -1)
        self._inputs.append(self._k_mat)
        self._mass_mat = Input(write_cms_rbd_file._spec().input_pin(7), 7, op, -1)
        self._inputs.append(self._mass_mat)
        self._c_mat = Input(write_cms_rbd_file._spec().input_pin(8), 8, op, -1)
        self._inputs.append(self._c_mat)
        self._rhs = Input(write_cms_rbd_file._spec().input_pin(9), 9, op, -1)
        self._inputs.append(self._rhs)
        self._dn = Input(write_cms_rbd_file._spec().input_pin(10), 10, op, -1)
        self._inputs.append(self._dn)
        self._dr_cross_n = Input(write_cms_rbd_file._spec().input_pin(11), 11, op, -1)
        self._inputs.append(self._dr_cross_n)
        self._drn = Input(write_cms_rbd_file._spec().input_pin(12), 12, op, -1)
        self._inputs.append(self._drn)
        self._dn_cross_n = Input(write_cms_rbd_file._spec().input_pin(13), 13, op, -1)
        self._inputs.append(self._dn_cross_n)
        self._dnx_y = Input(write_cms_rbd_file._spec().input_pin(14), 14, op, -1)
        self._inputs.append(self._dnx_y)
        self._dny_y = Input(write_cms_rbd_file._spec().input_pin(15), 15, op, -1)
        self._inputs.append(self._dny_y)
        self._dnz_y = Input(write_cms_rbd_file._spec().input_pin(16), 16, op, -1)
        self._inputs.append(self._dnz_y)
        self._dyx_n = Input(write_cms_rbd_file._spec().input_pin(17), 17, op, -1)
        self._inputs.append(self._dyx_n)
        self._dyy_n = Input(write_cms_rbd_file._spec().input_pin(18), 18, op, -1)
        self._inputs.append(self._dyy_n)
        self._dyz_n = Input(write_cms_rbd_file._spec().input_pin(19), 19, op, -1)
        self._inputs.append(self._dyz_n)
        self._dnxn = Input(write_cms_rbd_file._spec().input_pin(20), 20, op, -1)
        self._inputs.append(self._dnxn)
        self._dnyn = Input(write_cms_rbd_file._spec().input_pin(21), 21, op, -1)
        self._inputs.append(self._dnyn)
        self._dnzn = Input(write_cms_rbd_file._spec().input_pin(22), 22, op, -1)
        self._inputs.append(self._dnzn)
        self._file_path = Input(write_cms_rbd_file._spec().input_pin(23), 23, op, -1)
        self._inputs.append(self._file_path)

    @property
    def model_data(self):
        """Allows to connect model_data input to the operator.

        Data describing the finite element model

        Parameters
        ----------
        my_model_data : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.model_data.connect(my_model_data)
        >>> # or
        >>> op.inputs.model_data(my_model_data)
        """
        return self._model_data

    @property
    def center_of_mass(self):
        """Allows to connect center_of_mass input to the operator.

        Center of mass of the body

        Parameters
        ----------
        my_center_of_mass : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.center_of_mass.connect(my_center_of_mass)
        >>> # or
        >>> op.inputs.center_of_mass(my_center_of_mass)
        """
        return self._center_of_mass

    @property
    def inertia_relief(self):
        """Allows to connect inertia_relief input to the operator.

        Inertia matrix

        Parameters
        ----------
        my_inertia_relief : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.inertia_relief.connect(my_inertia_relief)
        >>> # or
        >>> op.inputs.inertia_relief(my_inertia_relief)
        """
        return self._inertia_relief

    @property
    def model_size(self):
        """Allows to connect model_size input to the operator.

        Size of the diagonal box containing the body

        Parameters
        ----------
        my_model_size : float

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.model_size.connect(my_model_size)
        >>> # or
        >>> op.inputs.model_size(my_model_size)
        """
        return self._model_size

    @property
    def master_node_coordinates(self):
        """Allows to connect master_node_coordinates input to the operator.

        Parameters
        ----------
        my_master_node_coordinates :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.master_node_coordinates.connect(my_master_node_coordinates)
        >>> # or
        >>> op.inputs.master_node_coordinates(my_master_node_coordinates)
        """
        return self._master_node_coordinates

    @property
    def v_trsf(self):
        """Allows to connect v_trsf input to the operator.

        Translational and rotational shape functions

        Parameters
        ----------
        my_v_trsf :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.v_trsf.connect(my_v_trsf)
        >>> # or
        >>> op.inputs.v_trsf(my_v_trsf)
        """
        return self._v_trsf

    @property
    def k_mat(self):
        """Allows to connect k_mat input to the operator.

        Parameters
        ----------
        my_k_mat : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.k_mat.connect(my_k_mat)
        >>> # or
        >>> op.inputs.k_mat(my_k_mat)
        """
        return self._k_mat

    @property
    def mass_mat(self):
        """Allows to connect mass_mat input to the operator.

        Parameters
        ----------
        my_mass_mat : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.mass_mat.connect(my_mass_mat)
        >>> # or
        >>> op.inputs.mass_mat(my_mass_mat)
        """
        return self._mass_mat

    @property
    def c_mat(self):
        """Allows to connect c_mat input to the operator.

        Parameters
        ----------
        my_c_mat : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.c_mat.connect(my_c_mat)
        >>> # or
        >>> op.inputs.c_mat(my_c_mat)
        """
        return self._c_mat

    @property
    def rhs(self):
        """Allows to connect rhs input to the operator.

        Parameters
        ----------
        my_rhs : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.rhs.connect(my_rhs)
        >>> # or
        >>> op.inputs.rhs(my_rhs)
        """
        return self._rhs

    @property
    def dn(self):
        """Allows to connect dn input to the operator.

        Parameters
        ----------
        my_dn :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dn.connect(my_dn)
        >>> # or
        >>> op.inputs.dn(my_dn)
        """
        return self._dn

    @property
    def dr_cross_n(self):
        """Allows to connect dr_cross_n input to the operator.

        Parameters
        ----------
        my_dr_cross_n :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dr_cross_n.connect(my_dr_cross_n)
        >>> # or
        >>> op.inputs.dr_cross_n(my_dr_cross_n)
        """
        return self._dr_cross_n

    @property
    def drn(self):
        """Allows to connect drn input to the operator.

        Parameters
        ----------
        my_drn :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.drn.connect(my_drn)
        >>> # or
        >>> op.inputs.drn(my_drn)
        """
        return self._drn

    @property
    def dn_cross_n(self):
        """Allows to connect dn_cross_n input to the operator.

        Parameters
        ----------
        my_dn_cross_n :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dn_cross_n.connect(my_dn_cross_n)
        >>> # or
        >>> op.inputs.dn_cross_n(my_dn_cross_n)
        """
        return self._dn_cross_n

    @property
    def dnx_y(self):
        """Allows to connect dnx_y input to the operator.

        Parameters
        ----------
        my_dnx_y :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dnx_y.connect(my_dnx_y)
        >>> # or
        >>> op.inputs.dnx_y(my_dnx_y)
        """
        return self._dnx_y

    @property
    def dny_y(self):
        """Allows to connect dny_y input to the operator.

        Parameters
        ----------
        my_dny_y :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dny_y.connect(my_dny_y)
        >>> # or
        >>> op.inputs.dny_y(my_dny_y)
        """
        return self._dny_y

    @property
    def dnz_y(self):
        """Allows to connect dnz_y input to the operator.

        Parameters
        ----------
        my_dnz_y :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dnz_y.connect(my_dnz_y)
        >>> # or
        >>> op.inputs.dnz_y(my_dnz_y)
        """
        return self._dnz_y

    @property
    def dyx_n(self):
        """Allows to connect dyx_n input to the operator.

        Parameters
        ----------
        my_dyx_n :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dyx_n.connect(my_dyx_n)
        >>> # or
        >>> op.inputs.dyx_n(my_dyx_n)
        """
        return self._dyx_n

    @property
    def dyy_n(self):
        """Allows to connect dyy_n input to the operator.

        Parameters
        ----------
        my_dyy_n :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dyy_n.connect(my_dyy_n)
        >>> # or
        >>> op.inputs.dyy_n(my_dyy_n)
        """
        return self._dyy_n

    @property
    def dyz_n(self):
        """Allows to connect dyz_n input to the operator.

        Parameters
        ----------
        my_dyz_n :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dyz_n.connect(my_dyz_n)
        >>> # or
        >>> op.inputs.dyz_n(my_dyz_n)
        """
        return self._dyz_n

    @property
    def dnxn(self):
        """Allows to connect dnxn input to the operator.

        Parameters
        ----------
        my_dnxn :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dnxn.connect(my_dnxn)
        >>> # or
        >>> op.inputs.dnxn(my_dnxn)
        """
        return self._dnxn

    @property
    def dnyn(self):
        """Allows to connect dnyn input to the operator.

        Parameters
        ----------
        my_dnyn :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dnyn.connect(my_dnyn)
        >>> # or
        >>> op.inputs.dnyn(my_dnyn)
        """
        return self._dnyn

    @property
    def dnzn(self):
        """Allows to connect dnzn input to the operator.

        Parameters
        ----------
        my_dnzn :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.dnzn.connect(my_dnzn)
        >>> # or
        >>> op.inputs.dnzn(my_dnzn)
        """
        return self._dnzn

    @property
    def file_path(self):
        """Allows to connect file_path input to the operator.

        Path with cms_rbd extension where the export
        occurs

        Parameters
        ----------
        my_file_path : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.result.write_cms_rbd_file()
        >>> op.inputs.file_path.connect(my_file_path)
        >>> # or
        >>> op.inputs.file_path(my_file_path)
        """
        return self._file_path


class OutputsWriteCmsRbdFile(_Outputs):
    """Intermediate class used to get outputs from
    write_cms_rbd_file operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.result.write_cms_rbd_file()
    >>> # Connect inputs : op.inputs. ...
    """

    def __init__(self, op: Operator):
        super().__init__(write_cms_rbd_file._spec().outputs, op)



"""
migrate_to_vtu
==============
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class migrate_to_vtu(Operator):
    """Extract all results from a datasources and exports them into vtu
    format. All the connected inputs are forwarded to the result
    providers operators.

    Parameters
    ----------
    time_scoping : Scoping, optional
        Time sets to export, default is all
    streams_container : StreamsContainer, optional
        Result file container allowed to be kept open
        to cache data
    data_sources : DataSources
        Result file path container, used if no
        streams are set
    directory : str
        Directory path
    base_name : str, optional
        Vtu base file name, (default is file)
    result1 : str, optional
        If operator's names are connected to this
        pin, only these results are exported
        (else all available results are
        exported)
    result2 : str, optional
        If operator's names are connected to this
        pin, only these results are exported
        (else all available results are
        exported)
    write_mode : str, optional
        Available are rawbinarycompressed, rawbinary,
        base64appended, base64inline, ascii,
        default is (rawbinarycompressed)


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.serialization.migrate_to_vtu()

    >>> # Make input connections
    >>> my_time_scoping = dpf.Scoping()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_directory = str()
    >>> op.inputs.directory.connect(my_directory)
    >>> my_base_name = str()
    >>> op.inputs.base_name.connect(my_base_name)
    >>> my_result1 = str()
    >>> op.inputs.result1.connect(my_result1)
    >>> my_result2 = str()
    >>> op.inputs.result2.connect(my_result2)
    >>> my_write_mode = str()
    >>> op.inputs.write_mode.connect(my_write_mode)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.serialization.migrate_to_vtu(
    ...     time_scoping=my_time_scoping,
    ...     streams_container=my_streams_container,
    ...     data_sources=my_data_sources,
    ...     directory=my_directory,
    ...     base_name=my_base_name,
    ...     result1=my_result1,
    ...     result2=my_result2,
    ...     write_mode=my_write_mode,
    ... )

    >>> # Get output data
    >>> result_path = op.outputs.path()
    """

    def __init__(
        self,
        time_scoping=None,
        streams_container=None,
        data_sources=None,
        directory=None,
        base_name=None,
        result1=None,
        result2=None,
        write_mode=None,
        config=None,
        server=None,
    ):
        super().__init__(name="migrate_to_vtu", config=config, server=server)
        self._inputs = InputsMigrateToVtu(self)
        self._outputs = OutputsMigrateToVtu(self)
        if time_scoping is not None:
            self.inputs.time_scoping.connect(time_scoping)
        if streams_container is not None:
            self.inputs.streams_container.connect(streams_container)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)
        if directory is not None:
            self.inputs.directory.connect(directory)
        if base_name is not None:
            self.inputs.base_name.connect(base_name)
        if result1 is not None:
            self.inputs.result1.connect(result1)
        if result2 is not None:
            self.inputs.result2.connect(result2)
        if write_mode is not None:
            self.inputs.write_mode.connect(write_mode)

    @staticmethod
    def _spec():
        description = """Extract all results from a datasources and exports them into vtu
            format. All the connected inputs are forwarded to the
            result providers operators."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="time_scoping",
                    type_names=["scoping", "vector<int32>"],
                    optional=True,
                    document="""Time sets to export, default is all""",
                ),
                3: PinSpecification(
                    name="streams_container",
                    type_names=["streams_container"],
                    optional=True,
                    document="""Result file container allowed to be kept open
        to cache data""",
                ),
                4: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""Result file path container, used if no
        streams are set""",
                ),
                20: PinSpecification(
                    name="directory",
                    type_names=["string"],
                    optional=False,
                    document="""Directory path""",
                ),
                21: PinSpecification(
                    name="base_name",
                    type_names=["string"],
                    optional=True,
                    document="""Vtu base file name, (default is file)""",
                ),
                30: PinSpecification(
                    name="result",
                    type_names=["string"],
                    optional=True,
                    document="""If operator's names are connected to this
        pin, only these results are exported
        (else all available results are
        exported)""",
                ),
                31: PinSpecification(
                    name="result",
                    type_names=["string"],
                    optional=True,
                    document="""If operator's names are connected to this
        pin, only these results are exported
        (else all available results are
        exported)""",
                ),
                100: PinSpecification(
                    name="write_mode",
                    type_names=["string"],
                    optional=True,
                    document="""Available are rawbinarycompressed, rawbinary,
        base64appended, base64inline, ascii,
        default is (rawbinarycompressed)""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="path",
                    type_names=["data_sources"],
                    optional=False,
                    document="""List of output vtu file path""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="migrate_to_vtu", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsMigrateToVtu
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsMigrateToVtu
        """
        return super().outputs


class InputsMigrateToVtu(_Inputs):
    """Intermediate class used to connect user inputs to
    migrate_to_vtu operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.serialization.migrate_to_vtu()
    >>> my_time_scoping = dpf.Scoping()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    >>> my_directory = str()
    >>> op.inputs.directory.connect(my_directory)
    >>> my_base_name = str()
    >>> op.inputs.base_name.connect(my_base_name)
    >>> my_result1 = str()
    >>> op.inputs.result1.connect(my_result1)
    >>> my_result2 = str()
    >>> op.inputs.result2.connect(my_result2)
    >>> my_write_mode = str()
    >>> op.inputs.write_mode.connect(my_write_mode)
    """

    def __init__(self, op: Operator):
        super().__init__(migrate_to_vtu._spec().inputs, op)
        self._time_scoping = Input(migrate_to_vtu._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._time_scoping)
        self._streams_container = Input(migrate_to_vtu._spec().input_pin(3), 3, op, -1)
        self._inputs.append(self._streams_container)
        self._data_sources = Input(migrate_to_vtu._spec().input_pin(4), 4, op, -1)
        self._inputs.append(self._data_sources)
        self._directory = Input(migrate_to_vtu._spec().input_pin(20), 20, op, -1)
        self._inputs.append(self._directory)
        self._base_name = Input(migrate_to_vtu._spec().input_pin(21), 21, op, -1)
        self._inputs.append(self._base_name)
        self._result1 = Input(migrate_to_vtu._spec().input_pin(30), 30, op, 0)
        self._inputs.append(self._result1)
        self._result2 = Input(migrate_to_vtu._spec().input_pin(31), 31, op, 1)
        self._inputs.append(self._result2)
        self._write_mode = Input(migrate_to_vtu._spec().input_pin(100), 100, op, -1)
        self._inputs.append(self._write_mode)

    @property
    def time_scoping(self):
        """Allows to connect time_scoping input to the operator.

        Time sets to export, default is all

        Parameters
        ----------
        my_time_scoping : Scoping

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.time_scoping.connect(my_time_scoping)
        >>> # or
        >>> op.inputs.time_scoping(my_time_scoping)
        """
        return self._time_scoping

    @property
    def streams_container(self):
        """Allows to connect streams_container input to the operator.

        Result file container allowed to be kept open
        to cache data

        Parameters
        ----------
        my_streams_container : StreamsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.streams_container.connect(my_streams_container)
        >>> # or
        >>> op.inputs.streams_container(my_streams_container)
        """
        return self._streams_container

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        Result file path container, used if no
        streams are set

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources

    @property
    def directory(self):
        """Allows to connect directory input to the operator.

        Directory path

        Parameters
        ----------
        my_directory : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.directory.connect(my_directory)
        >>> # or
        >>> op.inputs.directory(my_directory)
        """
        return self._directory

    @property
    def base_name(self):
        """Allows to connect base_name input to the operator.

        Vtu base file name, (default is file)

        Parameters
        ----------
        my_base_name : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.base_name.connect(my_base_name)
        >>> # or
        >>> op.inputs.base_name(my_base_name)
        """
        return self._base_name

    @property
    def result1(self):
        """Allows to connect result1 input to the operator.

        If operator's names are connected to this
        pin, only these results are exported
        (else all available results are
        exported)

        Parameters
        ----------
        my_result1 : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.result1.connect(my_result1)
        >>> # or
        >>> op.inputs.result1(my_result1)
        """
        return self._result1

    @property
    def result2(self):
        """Allows to connect result2 input to the operator.

        If operator's names are connected to this
        pin, only these results are exported
        (else all available results are
        exported)

        Parameters
        ----------
        my_result2 : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.result2.connect(my_result2)
        >>> # or
        >>> op.inputs.result2(my_result2)
        """
        return self._result2

    @property
    def write_mode(self):
        """Allows to connect write_mode input to the operator.

        Available are rawbinarycompressed, rawbinary,
        base64appended, base64inline, ascii,
        default is (rawbinarycompressed)

        Parameters
        ----------
        my_write_mode : str

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> op.inputs.write_mode.connect(my_write_mode)
        >>> # or
        >>> op.inputs.write_mode(my_write_mode)
        """
        return self._write_mode


class OutputsMigrateToVtu(_Outputs):
    """Intermediate class used to get outputs from
    migrate_to_vtu operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.serialization.migrate_to_vtu()
    >>> # Connect inputs : op.inputs. ...
    >>> result_path = op.outputs.path()
    """

    def __init__(self, op: Operator):
        super().__init__(migrate_to_vtu._spec().outputs, op)
        self._path = Output(migrate_to_vtu._spec().output_pin(0), 0, op)
        self._outputs.append(self._path)

    @property
    def path(self):
        """Allows to get path output of the operator

        Returns
        ----------
        my_path : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.serialization.migrate_to_vtu()
        >>> # Connect inputs : op.inputs. ...
        >>> result_path = op.outputs.path()
        """  # noqa: E501
        return self._path



"""
.. _ref_any:

Any
====================
"""
import traceback
import warnings

import ansys.dpf.core.server_types
from ansys.dpf.core import server as server_module
from ansys.dpf.core import errors
from ansys.dpf.core.common import type_to_internal_object_keyword
from ansys.dpf.gate import any_abstract_api


class Any:
    """Common wrapper representing any supported DPF Data Types.

    Parameters
    ----------
    any : ctypes.c_void_p, ansys.grpc.dpf.any_pb2.Any message, optional  # noqa: E501
    server : DPFServer, optional
        Server with channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Notes
    -----
    Class available with server's version starting at 7.0 (Ansys 2024 R1 pre0).
    """

    def __init__(self, any_dpf=None, server=None):
        # step 1: get server
        self._server = server_module.get_or_create_server(server)

        if any_dpf is None and not self._server.meet_version("7.0"):
            raise errors.DpfVersionNotSupported("7.0")

        self._api_instance = None

        # step 2: if object exists, take the instance, else create it
        if any_dpf is not None:
            self._internal_obj = any_dpf

        self._api.init_any_environment(self)  # creates stub when gRPC

        self._internal_type = None
        self._get_as_method = None

    @staticmethod
    def _type_to_new_from_get_as_method(any_dpf):
        from ansys.dpf.core import (
            field,
            property_field,
            generic_data_container,
            string_field,
            scoping,
            data_tree,
        )

        return [
            (
                int,
                any_dpf._api.any_new_from_int,
                any_dpf._api.any_get_as_int,
                any_dpf._api.any_new_from_int_on_client,
            ),
            (
                str,
                any_dpf._api.any_new_from_string,
                any_dpf._api.any_get_as_string,
                any_dpf._api.any_new_from_string_on_client,
            ),
            (
                float,
                any_dpf._api.any_new_from_double,
                any_dpf._api.any_get_as_double,
                any_dpf._api.any_new_from_double_on_client,
            ),
            (field.Field, any_dpf._api.any_new_from_field, any_dpf._api.any_get_as_field),
            (
                property_field.PropertyField,
                any_dpf._api.any_new_from_property_field,
                any_dpf._api.any_get_as_property_field,
            ),
            (
                string_field.StringField,
                any_dpf._api.any_new_from_string_field,
                any_dpf._api.any_get_as_string_field,
            ),
            (
                generic_data_container.GenericDataContainer,
                any_dpf._api.any_new_from_generic_data_container,
                any_dpf._api.any_get_as_generic_data_container,
            ),
            (
                scoping.Scoping,
                any_dpf._api.any_new_from_scoping,
                any_dpf._api.any_get_as_scoping,
            ),
            (
                data_tree.DataTree,
                any_dpf._api.any_new_from_data_tree,
                any_dpf._api.any_get_as_data_tree,
            ),
        ]

    @staticmethod
    def new_from(obj, server=None):
        """Return an Any instance from the given object.

        Parameters
        ----------
        obj : Object wrap as an Any

        Returns
        -------
        any : Any
            Wrapped any type.
        """

        innerServer = server if server is not None else obj._server

        if not innerServer.meet_version("7.0"):
            raise errors.DpfVersionNotSupported("7.0")

        any_dpf = Any(server=innerServer)

        for type_tuple in Any._type_to_new_from_get_as_method(any_dpf):
            if isinstance(obj, type_tuple[0]):
                # call respective new_from function
                if isinstance(server, ansys.dpf.core.server_types.InProcessServer) or not (
                    isinstance(obj, int) or isinstance(obj, str) or isinstance(obj, float)
                ):
                    any_dpf._internal_obj = type_tuple[1](obj)
                else:
                    any_dpf._internal_obj = type_tuple[3](innerServer.client, obj)
                # store get_as & type for casting back to original type
                any_dpf._internal_type = type_tuple[0]
                any_dpf._get_as_method = type_tuple[2]

                return any_dpf

        raise TypeError(f"{obj.__class__} is not currently supported by the Any class.")

    @property
    def _api(self) -> any_abstract_api.AnyAbstractAPI:
        from ansys.dpf.gate import any_capi, any_grpcapi

        if not self._api_instance:
            self._api_instance = self._server.get_api_for_type(
                capi=any_capi.AnyCAPI, grpcapi=any_grpcapi.AnyGRPCAPI
            )

        return self._api_instance

    def __str__(self):
        """Describe the entity.

        Returns
        -------
        description : str
            Description of the entity.
        """
        from ansys.dpf.core.core import _description

        return _description(self._internal_obj, self._server)

    def cast(self, output_type=None):
        """Cast the Any back to its original type.

        Parameters
        ----------
        output_type: output_type, optional
            Used when the Any instance was retrieved from the server.
            Not necessary when the instance was created using the
            :func:`ansys.dpf.core.Any.new_from`

        Returns
        -------
        type
            Original object instance
        """

        self._internal_type = output_type if output_type is not None else self._internal_type

        for type_tuple in Any._type_to_new_from_get_as_method(self):
            if self._internal_type == type_tuple[0]:
                # call the get_as function for the appropriate type
                internal_obj = type_tuple[2](self)
                if (
                    self._internal_type is int
                    or self._internal_type is str
                    or self._internal_type is float
                ):
                    obj = internal_obj
                else:
                    # get current type's constructors' variable keyword for passing the internal_obj
                    internal_obj_keyword = type_to_internal_object_keyword()[type_tuple[0]]

                    # wrap parameters in a dictionary for parameters expansion when calling
                    # constructor
                    keyword_args = {internal_obj_keyword: internal_obj, "server": self._server}
                    # call constructor
                    obj = type_tuple[0](**keyword_args)

                return obj

        raise TypeError(f"{output_type} is not currently supported by the Any class.")

    def __del__(self):
        try:
            if hasattr(self, "_deleter_func"):
                obj = self._deleter_func[1](self)
                if obj is not None:
                    self._deleter_func[0](obj)
        except Exception:
            warnings.warn(traceback.format_exc())



"""
mesh_info_provider
==================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class mesh_info_provider(Operator):
    """Reads the mesh information, such as number of elements (common
    property), number of faces (Cff plugins) or scoping of parts
    (LSDYNA plugins) on files contained in the streams or data
    sources.

    Parameters
    ----------
    time_scoping : int, optional
        Optional time/frequency set id of the mesh.
    streams_container : StreamsContainer, optional
        Streams (mesh file container) (optional)
    data_sources : DataSources
        If the stream is null, retrieves the file
        path from the data sources.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.metadata.mesh_info_provider()

    >>> # Make input connections
    >>> my_time_scoping = int()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.metadata.mesh_info_provider(
    ...     time_scoping=my_time_scoping,
    ...     streams_container=my_streams_container,
    ...     data_sources=my_data_sources,
    ... )

    >>> # Get output data
    >>> result_mesh_info = op.outputs.mesh_info()
    """

    def __init__(
        self,
        time_scoping=None,
        streams_container=None,
        data_sources=None,
        config=None,
        server=None,
    ):
        super().__init__(name="mesh_info_provider", config=config, server=server)
        self._inputs = InputsMeshInfoProvider(self)
        self._outputs = OutputsMeshInfoProvider(self)
        if time_scoping is not None:
            self.inputs.time_scoping.connect(time_scoping)
        if streams_container is not None:
            self.inputs.streams_container.connect(streams_container)
        if data_sources is not None:
            self.inputs.data_sources.connect(data_sources)

    @staticmethod
    def _spec():
        description = """Reads the mesh information, such as number of elements (common
            property), number of faces (Cff plugins) or scoping of
            parts (LSDYNA plugins) on files contained in the streams
            or data sources."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="time_scoping",
                    type_names=["int32"],
                    optional=True,
                    document="""Optional time/frequency set id of the mesh.""",
                ),
                3: PinSpecification(
                    name="streams_container",
                    type_names=["streams_container"],
                    optional=True,
                    document="""Streams (mesh file container) (optional)""",
                ),
                4: PinSpecification(
                    name="data_sources",
                    type_names=["data_sources"],
                    optional=False,
                    document="""If the stream is null, retrieves the file
        path from the data sources.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="mesh_info",
                    type_names=["generic_data_container"],
                    optional=False,
                    document="""""",
                    name_derived_class=["mesh_info"],
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="mesh_info_provider", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsMeshInfoProvider
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsMeshInfoProvider
        """
        return super().outputs


class InputsMeshInfoProvider(_Inputs):
    """Intermediate class used to connect user inputs to
    mesh_info_provider operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.metadata.mesh_info_provider()
    >>> my_time_scoping = int()
    >>> op.inputs.time_scoping.connect(my_time_scoping)
    >>> my_streams_container = dpf.StreamsContainer()
    >>> op.inputs.streams_container.connect(my_streams_container)
    >>> my_data_sources = dpf.DataSources()
    >>> op.inputs.data_sources.connect(my_data_sources)
    """

    def __init__(self, op: Operator):
        super().__init__(mesh_info_provider._spec().inputs, op)
        self._time_scoping = Input(mesh_info_provider._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._time_scoping)
        self._streams_container = Input(
            mesh_info_provider._spec().input_pin(3), 3, op, -1
        )
        self._inputs.append(self._streams_container)
        self._data_sources = Input(mesh_info_provider._spec().input_pin(4), 4, op, -1)
        self._inputs.append(self._data_sources)

    @property
    def time_scoping(self):
        """Allows to connect time_scoping input to the operator.

        Optional time/frequency set id of the mesh.

        Parameters
        ----------
        my_time_scoping : int

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.mesh_info_provider()
        >>> op.inputs.time_scoping.connect(my_time_scoping)
        >>> # or
        >>> op.inputs.time_scoping(my_time_scoping)
        """
        return self._time_scoping

    @property
    def streams_container(self):
        """Allows to connect streams_container input to the operator.

        Streams (mesh file container) (optional)

        Parameters
        ----------
        my_streams_container : StreamsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.mesh_info_provider()
        >>> op.inputs.streams_container.connect(my_streams_container)
        >>> # or
        >>> op.inputs.streams_container(my_streams_container)
        """
        return self._streams_container

    @property
    def data_sources(self):
        """Allows to connect data_sources input to the operator.

        If the stream is null, retrieves the file
        path from the data sources.

        Parameters
        ----------
        my_data_sources : DataSources

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.mesh_info_provider()
        >>> op.inputs.data_sources.connect(my_data_sources)
        >>> # or
        >>> op.inputs.data_sources(my_data_sources)
        """
        return self._data_sources


class OutputsMeshInfoProvider(_Outputs):
    """Intermediate class used to get outputs from
    mesh_info_provider operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.metadata.mesh_info_provider()
    >>> # Connect inputs : op.inputs. ...
    >>> result_mesh_info = op.outputs.mesh_info()
    """

    def __init__(self, op: Operator):
        super().__init__(mesh_info_provider._spec().outputs, op)
        self._mesh_info = Output(mesh_info_provider._spec().output_pin(0), 0, op)
        self._outputs.append(self._mesh_info)

    @property
    def mesh_info(self):
        """Allows to get mesh_info output of the operator

        Returns
        ----------
        my_mesh_info : mesh_info

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.metadata.mesh_info_provider()
        >>> # Connect inputs : op.inputs. ...
        >>> result_mesh_info = op.outputs.mesh_info()
        """  # noqa: E501
        return self._mesh_info



"""
time_freq_scoping_factory
=========================

Contains functions to simplify creating time frequency scopings.
"""

from ansys.dpf.core import Scoping
from ansys.dpf.core import errors as dpf_errors
from ansys.dpf.core.common import locations
from ansys.dpf.core.model import Model
from ansys.dpf.core.time_freq_support import TimeFreqSupport
from ansys.dpf.core.data_sources import DataSources
from ansys.dpf.core.operators.metadata import time_freq_provider

from ansys.dpf.core import types
from typing import Union


def scoping_by_load_step(load_step: int, server=None):
    """Create a specific ``ansys.dpf.core.Scoping`` for a given load step.

    The returned scoping describes a specific time frequency support element
    for a given load step.

    Parameters
    ----------
    load_step : int
        Load step ID of the specific time frequency scoping.
    server : DpfServer, optional
        Server with the channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Returns
    -------
    scoping : Scoping
        Scoping targeting one load step.
    """
    scoping = Scoping(server=server, ids=[load_step], location=locations.time_freq_step)
    return scoping


def scoping_by_load_steps(load_steps: list, server=None):
    """Create a specific :class:`ansys.dpf.core.Scoping` for a given list of load steps.

    The returned scoping describes a specific time frequency support element
    for a given list of load steps.

    Parameters
    ----------
    load_steps : list[int]
        List of load steps IDs of the specific time frequency scoping.
    server : DpfServer, optional
        Server with the channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Returns
    -------
    scoping : Scoping
        Scoping targeting several load_steps.
    """
    if not isinstance(load_steps, list):
        raise dpf_errors.InvalidTypeError("list", "load_steps")
    scoping = Scoping(server=server, ids=load_steps, location=locations.time_freq_step)
    return scoping


def scoping_by_set(cumulative_set, server=None):
    """Create a specific :class:`ansys.dpf.core.Scoping` for a given cumulative set index.

    The returned scoping describes a specific time frequency support element for a given
    cumulative set index.

    Parameters
    ----------
    cumulative_set : int
        Cumulative index of the set.
    server : DpfServer, optional
        Server with the channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Returns
    -------
    scoping : Scoping
        Scoping targeting one set (referenced by cumulative index).
    """
    scoping = Scoping(server=server, ids=[cumulative_set], location=locations.time_freq)
    return scoping


def scoping_by_sets(cumulative_sets, server=None):
    """Create a specific :class:`ansys.dpf.core.Scoping` for a given list of cumulative set indices.

    The returned scoping describes a specific time frequency support element for a given
    list of cumulative sets of indices.

    Parameters
    ----------
    cumulative_sets : list[int]
        List of cumulative indices of the sets.
    server : DpfServer, optional
        Server with the channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Returns
    -------
    scoping : Scoping
        Scoping targeting severals sets (referenced by cumulative indices).
    """
    if not isinstance(cumulative_sets, list):
        raise dpf_errors.InvalidTypeError("list", "cumulative_sets")
    scoping = Scoping(server=server, ids=cumulative_sets, location=locations.time_freq)
    return scoping


def scoping_by_step_and_substep(load_step_id, subset_id, time_freq_support):
    """Create a specific :class:`ansys.dpf.core.Scoping` for a given step and subset.

    The returned scoping describes a specific time frequency support element for a given
    step and substep.

    Parameters
    ----------
    load_step_id : int
        ID of the load step.
    subset_id : int
        ID of the subset.
    time_freq_support : TimeFreqSupport

    Returns
    -------
    scoping : Scoping
        Scoping based on a given step and substep of a time frequency support.
    """
    set_index = time_freq_support.get_cumulative_index(load_step_id - 1, subset_id - 1)
    scoping = Scoping(
        ids=[set_index + 1],
        location=locations.time_freq,
        server=time_freq_support._server,
    )
    return scoping


def scoping_by_step_and_substep_from_model(load_step_id, subset_id, model, server=None):
    """Create a specific ``ansys.dpf.core.Scoping`` for a given step and substep.

    The returned scoping describes a specific model's time freq support element for a given
    step and substep.

    Parameters
    ----------
    load_step_id : int
        ID of the step.
    subset_id : int
        ID of the subset.
    model : Model
    server : DpfServer, optional
        Server with the channel connected to the remote or local instance.
        The default is ``None``, in which case an attempt is made to use the
        global server.

    Returns
    -------
    scoping : Scoping
        Scoping based on a given step/substep of a model's time_freq_support."""
    return scoping_by_step_and_substep(load_step_id, subset_id, model.metadata.time_freq_support)


def scoping_on_all_time_freqs(obj: Union[TimeFreqSupport, Model, DataSources]):
    """Create a specific :class:`ansys.dpf.core.Scoping` with all time or
    frequency sets of a :class:`ansys.dpf.core.TimeFreqSupport` or a class:`ansys.dpf.core.Model`

    Parameters
    ----------
    tf_support_or_model : TimeFreqSupport, Model

    Returns
    -------
    scoping : Scoping
        Scoping with all time or frequency sets IDs.
    """
    tf_support = None
    if isinstance(obj, TimeFreqSupport):
        tf_support = obj
    elif isinstance(obj, Model):
        tf_support = obj.metadata.time_freq_support
    elif isinstance(obj, DataSources):
        tf_provider = time_freq_provider(data_sources=obj, server=obj._server)
        tf_support = tf_provider.get_output(output_type=types.time_freq_support)

    if tf_support == None:
        supported_types = f"{TimeFreqSupport}, {Model}, {DataSources}"
        raise TypeError(f"Given type was {type(obj)} while accepted types are {supported_types}")

    return Scoping(
        ids=range(1, len(tf_support.time_frequencies) + 1),
        location=locations.time_freq,
        server=tf_support._server,
    )



"""
enrich_materials
================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class enrich_materials(Operator):
    """Takes a MaterialContainer and a stream and enriches the
    MaterialContainer using stream data.

    Parameters
    ----------
    MaterialContainer :
    streams : StreamsContainer or FieldsContainer
    streams_mapping : Class Dataprocessing::Cpropertyfieldscontainer


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.logic.enrich_materials()

    >>> # Make input connections
    >>> my_MaterialContainer = dpf.()
    >>> op.inputs.MaterialContainer.connect(my_MaterialContainer)
    >>> my_streams = dpf.StreamsContainer()
    >>> op.inputs.streams.connect(my_streams)
    >>> my_streams_mapping = dpf.Class Dataprocessing::Cpropertyfieldscontainer()
    >>> op.inputs.streams_mapping.connect(my_streams_mapping)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.logic.enrich_materials(
    ...     MaterialContainer=my_MaterialContainer,
    ...     streams=my_streams,
    ...     streams_mapping=my_streams_mapping,
    ... )

    >>> # Get output data
    >>> result_MaterialContainer = op.outputs.MaterialContainer()
    """

    def __init__(
        self,
        MaterialContainer=None,
        streams=None,
        streams_mapping=None,
        config=None,
        server=None,
    ):
        super().__init__(name="enrich_materials", config=config, server=server)
        self._inputs = InputsEnrichMaterials(self)
        self._outputs = OutputsEnrichMaterials(self)
        if MaterialContainer is not None:
            self.inputs.MaterialContainer.connect(MaterialContainer)
        if streams is not None:
            self.inputs.streams.connect(streams)
        if streams_mapping is not None:
            self.inputs.streams_mapping.connect(streams_mapping)

    @staticmethod
    def _spec():
        description = """Takes a MaterialContainer and a stream and enriches the
            MaterialContainer using stream data."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="MaterialContainer",
                    type_names=["any"],
                    optional=False,
                    document="""""",
                ),
                1: PinSpecification(
                    name="streams",
                    type_names=["streams_container", "fields_container"],
                    optional=False,
                    document="""""",
                ),
                2: PinSpecification(
                    name="streams_mapping",
                    type_names=["class dataProcessing::CPropertyFieldsContainer"],
                    optional=False,
                    document="""""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="MaterialContainer",
                    type_names=["bool"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="enrich_materials", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsEnrichMaterials
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsEnrichMaterials
        """
        return super().outputs


class InputsEnrichMaterials(_Inputs):
    """Intermediate class used to connect user inputs to
    enrich_materials operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.logic.enrich_materials()
    >>> my_MaterialContainer = dpf.()
    >>> op.inputs.MaterialContainer.connect(my_MaterialContainer)
    >>> my_streams = dpf.StreamsContainer()
    >>> op.inputs.streams.connect(my_streams)
    >>> my_streams_mapping = dpf.Class Dataprocessing::Cpropertyfieldscontainer()
    >>> op.inputs.streams_mapping.connect(my_streams_mapping)
    """

    def __init__(self, op: Operator):
        super().__init__(enrich_materials._spec().inputs, op)
        self._MaterialContainer = Input(
            enrich_materials._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._MaterialContainer)
        self._streams = Input(enrich_materials._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._streams)
        self._streams_mapping = Input(enrich_materials._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._streams_mapping)

    @property
    def MaterialContainer(self):
        """Allows to connect MaterialContainer input to the operator.

        Parameters
        ----------
        my_MaterialContainer :

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.logic.enrich_materials()
        >>> op.inputs.MaterialContainer.connect(my_MaterialContainer)
        >>> # or
        >>> op.inputs.MaterialContainer(my_MaterialContainer)
        """
        return self._MaterialContainer

    @property
    def streams(self):
        """Allows to connect streams input to the operator.

        Parameters
        ----------
        my_streams : StreamsContainer or FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.logic.enrich_materials()
        >>> op.inputs.streams.connect(my_streams)
        >>> # or
        >>> op.inputs.streams(my_streams)
        """
        return self._streams

    @property
    def streams_mapping(self):
        """Allows to connect streams_mapping input to the operator.

        Parameters
        ----------
        my_streams_mapping : Class Dataprocessing::Cpropertyfieldscontainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.logic.enrich_materials()
        >>> op.inputs.streams_mapping.connect(my_streams_mapping)
        >>> # or
        >>> op.inputs.streams_mapping(my_streams_mapping)
        """
        return self._streams_mapping


class OutputsEnrichMaterials(_Outputs):
    """Intermediate class used to get outputs from
    enrich_materials operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.logic.enrich_materials()
    >>> # Connect inputs : op.inputs. ...
    >>> result_MaterialContainer = op.outputs.MaterialContainer()
    """

    def __init__(self, op: Operator):
        super().__init__(enrich_materials._spec().outputs, op)
        self._MaterialContainer = Output(enrich_materials._spec().output_pin(0), 0, op)
        self._outputs.append(self._MaterialContainer)

    @property
    def MaterialContainer(self):
        """Allows to get MaterialContainer output of the operator

        Returns
        ----------
        my_MaterialContainer : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.logic.enrich_materials()
        >>> # Connect inputs : op.inputs. ...
        >>> result_MaterialContainer = op.outputs.MaterialContainer()
        """  # noqa: E501
        return self._MaterialContainer



"""
field_high_pass_fc
==================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class field_high_pass_fc(Operator):
    """The high pass filter returns all the values above (but not equal to)
    the threshold value in input.

    Parameters
    ----------
    fields_container : FieldsContainer
        Field or fields container with only one field
        is expected
    threshold : float or Field
        A threshold scalar or a field containing one
        value is expected.
    both : bool, optional
        The default is false. if set to true, the
        complement of the filtered fields
        container is returned on output pin
        1.


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.filter.field_high_pass_fc()

    >>> # Make input connections
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_threshold = float()
    >>> op.inputs.threshold.connect(my_threshold)
    >>> my_both = bool()
    >>> op.inputs.both.connect(my_both)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.filter.field_high_pass_fc(
    ...     fields_container=my_fields_container,
    ...     threshold=my_threshold,
    ...     both=my_both,
    ... )

    >>> # Get output data
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(
        self, fields_container=None, threshold=None, both=None, config=None, server=None
    ):
        super().__init__(name="core::field::high_pass_fc", config=config, server=server)
        self._inputs = InputsFieldHighPassFc(self)
        self._outputs = OutputsFieldHighPassFc(self)
        if fields_container is not None:
            self.inputs.fields_container.connect(fields_container)
        if threshold is not None:
            self.inputs.threshold.connect(threshold)
        if both is not None:
            self.inputs.both.connect(both)

    @staticmethod
    def _spec():
        description = """The high pass filter returns all the values above (but not equal to)
            the threshold value in input."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Field or fields container with only one field
        is expected""",
                ),
                1: PinSpecification(
                    name="threshold",
                    type_names=["double", "field"],
                    optional=False,
                    document="""A threshold scalar or a field containing one
        value is expected.""",
                ),
                2: PinSpecification(
                    name="both",
                    type_names=["bool"],
                    optional=True,
                    document="""The default is false. if set to true, the
        complement of the filtered fields
        container is returned on output pin
        1.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="fields_container",
                    type_names=["fields_container"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="core::field::high_pass_fc", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsFieldHighPassFc
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsFieldHighPassFc
        """
        return super().outputs


class InputsFieldHighPassFc(_Inputs):
    """Intermediate class used to connect user inputs to
    field_high_pass_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.filter.field_high_pass_fc()
    >>> my_fields_container = dpf.FieldsContainer()
    >>> op.inputs.fields_container.connect(my_fields_container)
    >>> my_threshold = float()
    >>> op.inputs.threshold.connect(my_threshold)
    >>> my_both = bool()
    >>> op.inputs.both.connect(my_both)
    """

    def __init__(self, op: Operator):
        super().__init__(field_high_pass_fc._spec().inputs, op)
        self._fields_container = Input(
            field_high_pass_fc._spec().input_pin(0), 0, op, -1
        )
        self._inputs.append(self._fields_container)
        self._threshold = Input(field_high_pass_fc._spec().input_pin(1), 1, op, -1)
        self._inputs.append(self._threshold)
        self._both = Input(field_high_pass_fc._spec().input_pin(2), 2, op, -1)
        self._inputs.append(self._both)

    @property
    def fields_container(self):
        """Allows to connect fields_container input to the operator.

        Field or fields container with only one field
        is expected

        Parameters
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.field_high_pass_fc()
        >>> op.inputs.fields_container.connect(my_fields_container)
        >>> # or
        >>> op.inputs.fields_container(my_fields_container)
        """
        return self._fields_container

    @property
    def threshold(self):
        """Allows to connect threshold input to the operator.

        A threshold scalar or a field containing one
        value is expected.

        Parameters
        ----------
        my_threshold : float or Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.field_high_pass_fc()
        >>> op.inputs.threshold.connect(my_threshold)
        >>> # or
        >>> op.inputs.threshold(my_threshold)
        """
        return self._threshold

    @property
    def both(self):
        """Allows to connect both input to the operator.

        The default is false. if set to true, the
        complement of the filtered fields
        container is returned on output pin
        1.

        Parameters
        ----------
        my_both : bool

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.field_high_pass_fc()
        >>> op.inputs.both.connect(my_both)
        >>> # or
        >>> op.inputs.both(my_both)
        """
        return self._both


class OutputsFieldHighPassFc(_Outputs):
    """Intermediate class used to get outputs from
    field_high_pass_fc operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.filter.field_high_pass_fc()
    >>> # Connect inputs : op.inputs. ...
    >>> result_fields_container = op.outputs.fields_container()
    """

    def __init__(self, op: Operator):
        super().__init__(field_high_pass_fc._spec().outputs, op)
        self._fields_container = Output(field_high_pass_fc._spec().output_pin(0), 0, op)
        self._outputs.append(self._fields_container)

    @property
    def fields_container(self):
        """Allows to get fields_container output of the operator

        Returns
        ----------
        my_fields_container : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.filter.field_high_pass_fc()
        >>> # Connect inputs : op.inputs. ...
        >>> result_fields_container = op.outputs.fields_container()
        """  # noqa: E501
        return self._fields_container



import weakref


class DataSourcesOrStreamsConnector:
    def __init__(self, metadata):
        self._metadata = weakref.ref(metadata)

    @property
    def streams_provider(self):
        if self._metadata():
            return self._metadata().streams_provider
        return None

    @property
    def time_freq_support(self):
        if self._metadata():
            return self._metadata().time_freq_support
        return None

    @property
    def mesh_provider(self):
        if self._metadata():
            return self._metadata()._mesh_provider_cached
        return None

    @property
    def data_sources(self):
        if self._metadata():
            return self._metadata().data_sources
        return None

    def named_selection(self, name):
        if self._metadata():
            return self._metadata().named_selection(name)
        return None

    def __connect_op__(self, op, mesh_by_default=True):
        """Connect the data sources or the streams to the operator."""
        if self.streams_provider is not None and hasattr(op.inputs, "streams"):
            op.inputs.streams.connect(self.streams_provider.outputs)
        elif self.streams_provider is not None and hasattr(op.inputs, "streams_container"):
            op.inputs.streams_container.connect(self.streams_provider.outputs)
        elif self.data_sources is not None and hasattr(op.inputs, "data_sources"):
            op.inputs.data_sources.connect(self.data_sources)

        if mesh_by_default and self.mesh_provider and hasattr(op.inputs, "mesh"):
            op.inputs.mesh.connect(self.mesh_provider)



"""
merge_property_fields
=====================
Autogenerated DPF operator classes.
"""
from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class merge_property_fields(Operator):
    """Assembles a set of property fields into a unique one.

    Parameters
    ----------
    vector_shared_ptr_property_field__1 : PropertyField or Class
        Dataprocessing::Cpropertyfieldscontainer
        Either a property fields container, a vector
        of property fields to merge or
        property fields from pin 0 to ...
    vector_shared_ptr_property_field__2 : PropertyField or Class
        Dataprocessing::Cpropertyfieldscontainer
        Either a property fields container, a vector
        of property fields to merge or
        property fields from pin 0 to ...


    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.utility.merge_property_fields()

    >>> # Make input connections
    >>> my_vector_shared_ptr_property_field__1 = dpf.PropertyField()
    >>> op.inputs.vector_shared_ptr_property_field__1.connect(my_vector_shared_ptr_property_field__1)
    >>> my_vector_shared_ptr_property_field__2 = dpf.PropertyField()
    >>> op.inputs.vector_shared_ptr_property_field__2.connect(my_vector_shared_ptr_property_field__2)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.utility.merge_property_fields(
    ...     vector_shared_ptr_property_field__1=my_vector_shared_ptr_property_field__1,
    ...     vector_shared_ptr_property_field__2=my_vector_shared_ptr_property_field__2,
    ... )

    >>> # Get output data
    >>> result_property_field = op.outputs.property_field()
    """

    def __init__(
        self,
        vector_shared_ptr_property_field__1=None,
        vector_shared_ptr_property_field__2=None,
        config=None,
        server=None,
    ):
        super().__init__(name="merge::property_field", config=config, server=server)
        self._inputs = InputsMergePropertyFields(self)
        self._outputs = OutputsMergePropertyFields(self)
        if vector_shared_ptr_property_field__1 is not None:
            self.inputs.vector_shared_ptr_property_field__1.connect(
                vector_shared_ptr_property_field__1
            )
        if vector_shared_ptr_property_field__2 is not None:
            self.inputs.vector_shared_ptr_property_field__2.connect(
                vector_shared_ptr_property_field__2
            )

    @staticmethod
    def _spec():
        description = """Assembles a set of property fields into a unique one."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="vector_shared_ptr_property_field__",
                    type_names=[
                        "property_field",
                        "class dataProcessing::CPropertyFieldsContainer",
                    ],
                    optional=False,
                    document="""Either a property fields container, a vector
        of property fields to merge or
        property fields from pin 0 to ...""",
                ),
                1: PinSpecification(
                    name="vector_shared_ptr_property_field__",
                    type_names=[
                        "property_field",
                        "class dataProcessing::CPropertyFieldsContainer",
                    ],
                    optional=False,
                    document="""Either a property fields container, a vector
        of property fields to merge or
        property fields from pin 0 to ...""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="property_field",
                    type_names=["property_field"],
                    optional=False,
                    document="""""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="merge::property_field", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsMergePropertyFields
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsMergePropertyFields
        """
        return super().outputs


class InputsMergePropertyFields(_Inputs):
    """Intermediate class used to connect user inputs to
    merge_property_fields operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.merge_property_fields()
    >>> my_vector_shared_ptr_property_field__1 = dpf.PropertyField()
    >>> op.inputs.vector_shared_ptr_property_field__1.connect(my_vector_shared_ptr_property_field__1)
    >>> my_vector_shared_ptr_property_field__2 = dpf.PropertyField()
    >>> op.inputs.vector_shared_ptr_property_field__2.connect(my_vector_shared_ptr_property_field__2)
    """

    def __init__(self, op: Operator):
        super().__init__(merge_property_fields._spec().inputs, op)
        self._vector_shared_ptr_property_field__1 = Input(
            merge_property_fields._spec().input_pin(0), 0, op, 0
        )
        self._inputs.append(self._vector_shared_ptr_property_field__1)
        self._vector_shared_ptr_property_field__2 = Input(
            merge_property_fields._spec().input_pin(1), 1, op, 1
        )
        self._inputs.append(self._vector_shared_ptr_property_field__2)

    @property
    def vector_shared_ptr_property_field__1(self):
        """Allows to connect vector_shared_ptr_property_field__1 input to the operator.

        Either a property fields container, a vector
        of property fields to merge or
        property fields from pin 0 to ...

        Parameters
        ----------
        my_vector_shared_ptr_property_field__1 : PropertyField or Class
        Dataprocessing::Cpropertyfieldscontainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.merge_property_fields()
        >>> op.inputs.vector_shared_ptr_property_field__1.connect(my_vector_shared_ptr_property_field__1)
        >>> # or
        >>> op.inputs.vector_shared_ptr_property_field__1(my_vector_shared_ptr_property_field__1)
        """
        return self._vector_shared_ptr_property_field__1

    @property
    def vector_shared_ptr_property_field__2(self):
        """Allows to connect vector_shared_ptr_property_field__2 input to the operator.

        Either a property fields container, a vector
        of property fields to merge or
        property fields from pin 0 to ...

        Parameters
        ----------
        my_vector_shared_ptr_property_field__2 : PropertyField or Class
        Dataprocessing::Cpropertyfieldscontainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.merge_property_fields()
        >>> op.inputs.vector_shared_ptr_property_field__2.connect(my_vector_shared_ptr_property_field__2)
        >>> # or
        >>> op.inputs.vector_shared_ptr_property_field__2(my_vector_shared_ptr_property_field__2)
        """
        return self._vector_shared_ptr_property_field__2


class OutputsMergePropertyFields(_Outputs):
    """Intermediate class used to get outputs from
    merge_property_fields operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.utility.merge_property_fields()
    >>> # Connect inputs : op.inputs. ...
    >>> result_property_field = op.outputs.property_field()
    """

    def __init__(self, op: Operator):
        super().__init__(merge_property_fields._spec().outputs, op)
        self._property_field = Output(
            merge_property_fields._spec().output_pin(0), 0, op
        )
        self._outputs.append(self._property_field)

    @property
    def property_field(self):
        """Allows to get property_field output of the operator

        Returns
        ----------
        my_property_field : PropertyField

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.utility.merge_property_fields()
        >>> # Connect inputs : op.inputs. ...
        >>> result_property_field = op.outputs.property_field()
        """  # noqa: E501
        return self._property_field
